@@ -331,29 +331,37 @@ PHP_FUNCTION(xcache_get_opcode_spec)
 PHP_FUNCTION(xcache_get_special_value)
 {
 	zval *value;
+	zval value_copied;
 
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z", &value) == FAILURE) {
 		return;
 	}
+	value_copied = *value;
+	value = &value_copied;
 
 	switch ((Z_TYPE_P(value) & IS_CONSTANT_TYPE_MASK)) {
 	case IS_CONSTANT:
-		*return_value = *value;
-		zval_copy_ctor(return_value);
-		return_value->type = UNISW(IS_STRING, UG(unicode) ? IS_UNICODE : IS_STRING);
+		value->type = UNISW(IS_STRING, UG(unicode) ? IS_UNICODE : IS_STRING);
+		RETURN_ZVAL(value, 1, 0);
 		break;
 
+#ifdef IS_CONSTANT_ARRAY
 	case IS_CONSTANT_ARRAY:
-		*return_value = *value;
-		zval_copy_ctor(return_value);
-		return_value->type = IS_ARRAY;
+		value->type = IS_ARRAY;
+		RETURN_ZVAL(value, 1, 0);
 		break;
+#endif
+
+#ifdef IS_CONSTANT_AST
+	case IS_CONSTANT_AST:
+		RETURN_NULL();
+		break;
+#endif
 
 	default:
 		if ((Z_TYPE_P(value) & ~IS_CONSTANT_TYPE_MASK)) {
-			*return_value = *value;
-			zval_copy_ctor(return_value);
-			return_value->type &= IS_CONSTANT_TYPE_MASK;
+			value->type &= IS_CONSTANT_TYPE_MASK;
+			RETURN_ZVAL(value, 1, 0);
 		}
 		else {
 			RETURN_NULL();
@@ -728,12 +736,9 @@ static int xc_zend_startup(zend_extension *extension) /* {{{ */
 
 	ext = (zend_extension *) zend_extensions.head->data;
 	if (strcmp(ext->name, XCACHE_NAME) != 0) {
-		zend_error(E_WARNING, "XCache failed to load itself as the before \"%s\". compatibility downgraded", ext->name);
+		zend_error(E_WARNING, "XCache failed to load itself to before zend_extension=\"%s\". compatibility downgraded", ext->name);
 	}
 
-	old_compile_file = zend_compile_file;
-	zend_compile_file = xc_check_initial_compile_file;
-
 	for (ext = (zend_extension *) zend_llist_get_first_ex(&zend_extensions, &lpos);
 			ext;
 			ext = (zend_extension *) zend_llist_get_next_ex(&zend_extensions, &lpos)) {
@@ -820,6 +825,9 @@ static PHP_MINIT_FUNCTION(xcache) /* {{{ */
 
 	/* must be the first */
 	xcache_zend_extension_add(&xc_zend_extension_entry, 1);
+	old_compile_file = zend_compile_file;
+	zend_compile_file = xc_check_initial_compile_file;
+
 #ifdef HAVE_XCACHE_OPTIMIZER
 	xc_optimizer_startup_module();
 #endif
