@@ -71,6 +71,8 @@ const char *xc_get_data_type(zend_uchar data_type)
 /* {{{ xc_get_opcode */
 #if PHP_MAJOR_VERSION >= 6
 #	include "xc_const_string_opcodes_php6.x.h"
+#elif defined(ZEND_ENGINE_2_6)
+#	include "xc_const_string_opcodes_php5.6.h"
 #elif defined(ZEND_ENGINE_2_5)
 #	include "xc_const_string_opcodes_php5.5.h"
 #elif defined(ZEND_ENGINE_2_4)
